Documentation
¶
Index ¶
- type ApiServerSourceLister
- type ApiServerSourceListerExpansion
- type ApiServerSourceNamespaceLister
- type ApiServerSourceNamespaceListerExpansion
- type ContainerSourceLister
- type ContainerSourceListerExpansion
- type ContainerSourceNamespaceLister
- type ContainerSourceNamespaceListerExpansion
- type CronJobSourceLister
- type CronJobSourceListerExpansion
- type CronJobSourceNamespaceLister
- type CronJobSourceNamespaceListerExpansion
- type SinkBindingLister
- type SinkBindingListerExpansion
- type SinkBindingNamespaceLister
- type SinkBindingNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ApiServerSourceLister ¶
type ApiServerSourceLister interface {
// List lists all ApiServerSources in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.ApiServerSource, err error)
// ApiServerSources returns an object that can list and get ApiServerSources.
ApiServerSources(namespace string) ApiServerSourceNamespaceLister
ApiServerSourceListerExpansion
}
ApiServerSourceLister helps list ApiServerSources.
func NewApiServerSourceLister ¶
func NewApiServerSourceLister(indexer cache.Indexer) ApiServerSourceLister
NewApiServerSourceLister returns a new ApiServerSourceLister.
type ApiServerSourceListerExpansion ¶
type ApiServerSourceListerExpansion interface{}
ApiServerSourceListerExpansion allows custom methods to be added to ApiServerSourceLister.
type ApiServerSourceNamespaceLister ¶
type ApiServerSourceNamespaceLister interface {
// List lists all ApiServerSources in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.ApiServerSource, err error)
// Get retrieves the ApiServerSource from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.ApiServerSource, error)
ApiServerSourceNamespaceListerExpansion
}
ApiServerSourceNamespaceLister helps list and get ApiServerSources.
type ApiServerSourceNamespaceListerExpansion ¶
type ApiServerSourceNamespaceListerExpansion interface{}
ApiServerSourceNamespaceListerExpansion allows custom methods to be added to ApiServerSourceNamespaceLister.
type ContainerSourceLister ¶
type ContainerSourceLister interface {
// List lists all ContainerSources in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.ContainerSource, err error)
// ContainerSources returns an object that can list and get ContainerSources.
ContainerSources(namespace string) ContainerSourceNamespaceLister
ContainerSourceListerExpansion
}
ContainerSourceLister helps list ContainerSources.
func NewContainerSourceLister ¶
func NewContainerSourceLister(indexer cache.Indexer) ContainerSourceLister
NewContainerSourceLister returns a new ContainerSourceLister.
type ContainerSourceListerExpansion ¶
type ContainerSourceListerExpansion interface{}
ContainerSourceListerExpansion allows custom methods to be added to ContainerSourceLister.
type ContainerSourceNamespaceLister ¶
type ContainerSourceNamespaceLister interface {
// List lists all ContainerSources in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.ContainerSource, err error)
// Get retrieves the ContainerSource from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.ContainerSource, error)
ContainerSourceNamespaceListerExpansion
}
ContainerSourceNamespaceLister helps list and get ContainerSources.
type ContainerSourceNamespaceListerExpansion ¶
type ContainerSourceNamespaceListerExpansion interface{}
ContainerSourceNamespaceListerExpansion allows custom methods to be added to ContainerSourceNamespaceLister.
type CronJobSourceLister ¶
type CronJobSourceLister interface {
// List lists all CronJobSources in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.CronJobSource, err error)
// CronJobSources returns an object that can list and get CronJobSources.
CronJobSources(namespace string) CronJobSourceNamespaceLister
CronJobSourceListerExpansion
}
CronJobSourceLister helps list CronJobSources.
func NewCronJobSourceLister ¶
func NewCronJobSourceLister(indexer cache.Indexer) CronJobSourceLister
NewCronJobSourceLister returns a new CronJobSourceLister.
type CronJobSourceListerExpansion ¶
type CronJobSourceListerExpansion interface{}
CronJobSourceListerExpansion allows custom methods to be added to CronJobSourceLister.
type CronJobSourceNamespaceLister ¶
type CronJobSourceNamespaceLister interface {
// List lists all CronJobSources in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.CronJobSource, err error)
// Get retrieves the CronJobSource from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.CronJobSource, error)
CronJobSourceNamespaceListerExpansion
}
CronJobSourceNamespaceLister helps list and get CronJobSources.
type CronJobSourceNamespaceListerExpansion ¶
type CronJobSourceNamespaceListerExpansion interface{}
CronJobSourceNamespaceListerExpansion allows custom methods to be added to CronJobSourceNamespaceLister.
type SinkBindingLister ¶ added in v0.11.0
type SinkBindingLister interface {
// List lists all SinkBindings in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.SinkBinding, err error)
// SinkBindings returns an object that can list and get SinkBindings.
SinkBindings(namespace string) SinkBindingNamespaceLister
SinkBindingListerExpansion
}
SinkBindingLister helps list SinkBindings.
func NewSinkBindingLister ¶ added in v0.11.0
func NewSinkBindingLister(indexer cache.Indexer) SinkBindingLister
NewSinkBindingLister returns a new SinkBindingLister.
type SinkBindingListerExpansion ¶ added in v0.11.0
type SinkBindingListerExpansion interface{}
SinkBindingListerExpansion allows custom methods to be added to SinkBindingLister.
type SinkBindingNamespaceLister ¶ added in v0.11.0
type SinkBindingNamespaceLister interface {
// List lists all SinkBindings in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.SinkBinding, err error)
// Get retrieves the SinkBinding from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.SinkBinding, error)
SinkBindingNamespaceListerExpansion
}
SinkBindingNamespaceLister helps list and get SinkBindings.
type SinkBindingNamespaceListerExpansion ¶ added in v0.11.0
type SinkBindingNamespaceListerExpansion interface{}
SinkBindingNamespaceListerExpansion allows custom methods to be added to SinkBindingNamespaceLister.